@@ -17,7 +17,13 @@
 
 #include "link-includes.h"
 
+#ifdef HAVE_SQLITE
 Boolean check_db(const char *lang);
 Dictionary dictionary_create_from_db(const char *lang);
+#else
+
+Boolean check_db(const char *lang) { return false; }
+Dictionary dictionary_create_from_db(const char *lang) { return NULL; }
+#endif /* HAVE_SQLITE */
 
 #endif /* READ_SQL_H */
