@@ -3,8 +3,7 @@
 /* All rights reserved                                                   */
 /*                                                                       */
 /* Use of the link grammar parsing system is subject to the terms of the */
-/* license set forth in the LICENSE file included with this software,    */
-/* and also available at http://www.link.cs.cmu.edu/link/license.html    */
+/* license set forth in the LICENSE file included with this software.    */
 /* This license allows free redistribution and use in source and binary  */
 /* forms, with or without modification, subject to certain conditions.   */
 /*                                                                       */
@@ -20,6 +19,7 @@
 #include <string.h>
 #include "api-structures.h"
 #include "disjuncts.h"
+#include "structures.h"
 #include "utilities.h"
 
 /* ========================================================= */
@@ -58,10 +58,7 @@ void lg_compute_disjunct_strings(Sentence sent, Linkage_info *lifo)
 	djlist = djcount + nwords;
 	djloco = djlist + nwords*nlinks;
 
-	/* Decrement nwords, so as to ignore the RIGHT-WALL */
-	nwords --;
-
-	for (w=0; w<nwords; w++)
+	for (w = 0; w < nwords; w++)
 	{
 		djcount[w] = 0;
 	}
@@ -92,13 +89,13 @@ void lg_compute_disjunct_strings(Sentence sent, Linkage_info *lifo)
 #endif
 	}
 
-	/* Process each word in the sentence (skipping LEFT-WALL, which is
-	 * word 0. */
-	for (w=1; w<nwords; w++)
+	/* Process each word in the sentence
+	 * (Hmm... should we be skipping LEFT-WALL, which is word 0? */
+	for (w = 0; w < nwords; w++)
 	{
 		/* Sort the disjuncts for this word. -- bubble sort */
 		int slot = djcount[w];
-		for (i=0; i<slot; i++)
+		for (i = 0; i < slot; i++)
 		{
 			int j;
 			for (j=i+1; j<slot; j++)
@@ -118,7 +115,7 @@ void lg_compute_disjunct_strings(Sentence sent, Linkage_info *lifo)
 		/* Create the disjunct string */
 		left = sizeof(djstr);
 		copied = 0;
-		for (i=0; i<slot; i++)
+		for (i = 0; i < slot; i++)
 		{
 			int dj = djlist[w*nlinks + i];
 			copied += lg_strlcpy(djstr+copied, pi->link_array[dj].name, left);
