@@ -5,14 +5,16 @@
 /* All rights reserved                                                   */
 /*                                                                       */
 /* Use of the link grammar parsing system is subject to the terms of the */
-/* license set forth in the LICENSE file included with this software,    */
-/* and also available at http://www.link.cs.cmu.edu/link/license.html    */
+/* license set forth in the LICENSE file included with this software.    */
 /* This license allows free redistribution and use in source and binary  */
 /* forms, with or without modification, subject to certain conditions.   */
 /*                                                                       */
 /*************************************************************************/
 
-#include "api.h"
+#include "count.h"
+#include "fast-match.h"
+#include "extract-links.h"
+#include "word-utils.h"
 
 /**
  * The first thing we do is we build a data structure to represent the
