@@ -4,8 +4,7 @@
 /* All rights reserved                                                   */
 /*                                                                       */
 /* Use of the link grammar parsing system is subject to the terms of the */
-/* license set forth in the LICENSE file included with this software,    */
-/* and also available at http://www.link.cs.cmu.edu/link/license.html    */
+/* license set forth in the LICENSE file included with this software.    */
 /* This license allows free redistribution and use in source and binary  */
 /* forms, with or without modification, subject to certain conditions.   */
 /*                                                                       */
@@ -21,7 +20,8 @@ to the caller to ensure that the pointers always point to something useful.
 
 #include <memory.h>
 
-#include "api.h"
+#include "post-process.h"
+#include "pp_linkset.h"
 
 #define LINKSET_SPARSENESS 2
 #define LINKSET_SEED_VALUE 37
