@@ -15,9 +15,6 @@
 void   print_disjunct_counts(Sentence sent);
 void   print_expression_sizes(Sentence sent);
 void   compute_chosen_words(Sentence sent, Linkage linkage);
-struct tokenpos
-{
-	int wi;
-	int ai;
-} print_sentence_word_alternatives(Sentence sent, bool debugprint,
-			void (*display)(Dictionary, const char *), const char * findtoken);
+struct tokenpos;
+void   print_sentence_word_alternatives(Sentence sent, bool debugprint,
+       void (*display)(Dictionary, const char *), struct tokenpos *);
