@@ -1,19 +1,26 @@
 /*************************************************************************/
 /* Copyright (c) 2004                                                    */
 /* Daniel Sleator, David Temperley, and John Lafferty                    */
+/* Copyright (c) 2009, 2013 Linas Vepstas                                */
 /* All rights reserved                                                   */
 /*                                                                       */
 /* Use of the link grammar parsing system is subject to the terms of the */
-/* license set forth in the LICENSE file included with this software,    */
-/* and also available at http://www.link.cs.cmu.edu/link/license.html    */
+/* license set forth in the LICENSE file included with this software.    */
 /* This license allows free redistribution and use in source and binary  */
 /* forms, with or without modification, subject to certain conditions.   */
 /*                                                                       */
 /*************************************************************************/
 
-#include "api.h"
+#include "api-structures.h"
+#include "count.h"
+#include "dict-api.h"  /* for print_expression when debugging */
 #include "disjunct-utils.h"
+#include "externs.h"
+#include "post-process.h"
+#include "print.h"
+#include "prune.h"
 #include "resources.h"
+#include "word-utils.h"
 
 #define CONTABSZ 8192
 typedef Connector * connector_table;
@@ -280,7 +287,7 @@ static void zero_connector_table(connector_table *ct)
 	memset(ct, 0, sizeof(Connector *) * CONTABSZ);
 }
 
-/** 
+/**
  * This function puts connector c into the connector table
  * if one like it isn't already there.
  */
@@ -294,7 +301,7 @@ static void insert_connector(connector_table *ct, Connector * c)
 	for (e = ct[h]; e != NULL; e = e->tableNext)
 	{
 #ifdef USE_FAT_LINKAGES
-		if ((strcmp(c->string, e->string) == 0) && 
+		if ((strcmp(c->string, e->string) == 0) &&
 		    (c->priority == e->priority) &&
 		    (c->label == e->label))
 			return;
@@ -307,6 +314,7 @@ static void insert_connector(connector_table *ct, Connector * c)
 	ct[h] = c;
 }
 
+#if 0 /* DEAD_CODE_NOT_USED_ANYWHERE */
 void prune(Sentence sent)
 {
 	Connector *e, *f;
@@ -321,7 +329,7 @@ void prune(Sentence sent)
 #endif /* USE_FAT_LINKAGES */
 
 	N_deleted = 1;  /* a lie to make it always do at least 2 passes */
-	while(1)
+	while (1)
 	{
 		/* Left-to-right pass */
 		zero_connector_table(ct);
@@ -440,6 +448,7 @@ void prune(Sentence sent)
 		N_deleted = 0;
 	}
 }
+#endif /* DEAD_CODE_NOT_USED_ANYWHERE */
 
 /*
    The second algorithm eliminates disjuncts that are dominated by
@@ -464,7 +473,7 @@ void prune(Sentence sent)
       think it does the fat link matches properly.   (See the comment
       in and.c for more information about matching fat links.)  This is
       irrelevant because of (1).
-   
+
   (3) The linkage that is eliminated by this, might just be the one that
       passes post-processing, as the following example shows.
       This is pretty silly, and should probably be changed.
@@ -473,8 +482,8 @@ void prune(Sentence sent)
 Accepted (2 linkages, 1 with no P.P. violations)
   Linkage 1, cost vector = (0, 0, 7)
 
-   +------------------G-----------------+      
-   +-----R-----+----CL----+             |      
+   +------------------G-----------------+
+   +-----R-----+----CL----+             |
    +---O---+   |   +---D--+---S---+     +--I-+-AI-+
    |       |   |   |      |       |     |    |    |
 telling.g John how our program.n works would be stupid
@@ -493,8 +502,8 @@ telling.g John how our program.n works would be stupid
 >
   Linkage 2 (bad), cost vector = (0, 0, 7)
 
-   +------------------G-----------------+      
-   +-----R-----+----CL----+             |      
+   +------------------G-----------------+
+   +-----R-----+----CL----+             |
    +---O---+   |   +---D--+---S---+     +--I-+-AI-+
    |       |   |   |      |       |     |    |    |
 telling.g John how our program.n works would be stupid
@@ -941,7 +950,7 @@ static void clean_up_expressions(Sentence sent, int w)
 }
 
 /* #define DBG(X) X */
-#define DBG(X) 
+#define DBG(X)
 
 void expression_prune(Sentence sent)
 {
@@ -955,7 +964,7 @@ void expression_prune(Sentence sent)
 
 	N_deleted = 1;  /* a lie to make it always do at least 2 passes */
 
-	while(1)
+	while (1)
 	{
 		/* Left-to-right pass */
 		/* For every word */
@@ -1140,7 +1149,7 @@ static void power_table_delete(power_table *pt)
 		}
 		xfree((char *)pt->r_table[w], pt->r_table_size[w] * sizeof (C_list *));
 	}
-	free(pt);
+	xfree(pt, sizeof(power_table));
 }
 
 /**
@@ -1180,7 +1189,7 @@ static power_table * power_table_new(Sentence sent)
 	Disjunct * d, * xd, * head;
 	Connector * c;
 
-	pt = (power_table *) malloc (sizeof(power_table));
+	pt = (power_table *) xalloc (sizeof(power_table));
 	pt->power_table_size = sent->length;
 
    /* First, we initialize the word fields of the connectors, and
@@ -1207,7 +1216,7 @@ static power_table * power_table_new(Sentence sent)
 		/* The below uses variable-sized hash tables. This seems to
 		 * provide performance that is equal or better than the best
 		 * fixed-size prformance.
-		 * The best fixed-size performance seems to come at about 
+		 * The best fixed-size performance seems to come at about
 		 * a 1K table size, for both English and Russian. (Both have
 		 * about 100 fixed link-types, and many thousands of auto-genned
 		 * link types (IDxxx idioms for both, LLxxx suffix links for
@@ -1412,7 +1421,7 @@ left_table_search(prune_context *pc, int w, Connector *c,
 /**
  * Take this connector list, and try to match it with the words
  * w-1, w-2, w-3...  Returns the word to which the first connector of
- * the list could possibly be matched.  If c is NULL, returns w.  If 
+ * the list could possibly be matched.  If c is NULL, returns w.  If
  * there is no way to match this list, it returns a negative number.
  * If it does find a way to match it, it updates the c->word fields
  * correctly.
@@ -1488,7 +1497,7 @@ int power_prune(Sentence sent, int mode, Parse_Options opts)
 	Connector *c;
 	int w, N_deleted, total_deleted;
 
-	pc = (prune_context *) malloc (sizeof(prune_context));
+	pc = (prune_context *) xalloc (sizeof(prune_context));
 	pc->power_cost = 0;
 	pc->null_links = (opts->min_null_count > 0);
 	pc->N_changed = 1;  /* forces it always to make at least two passes */
@@ -1602,7 +1611,7 @@ int power_prune(Sentence sent, int mode, Parse_Options opts)
 		print_disjunct_counts(sent);
 	}
 
-	free(pc);
+	xfree(pc, sizeof(prune_context));
 	return total_deleted;
 }
 
@@ -1691,7 +1700,7 @@ static multiset_table * cms_table_new(void)
 	multiset_table *mt;
 	int i;
 
-	mt = (multiset_table *) malloc(sizeof(multiset_table));
+	mt = (multiset_table *) xalloc(sizeof(multiset_table));
 
 	for (i=0; i<CMS_SIZE; i++) {
 		mt->cms_table[i] = NULL;
@@ -1711,7 +1720,7 @@ static void cms_table_delete(multiset_table *mt)
 			xfree(cms, sizeof(Cms));
 		}
 	}
-	free(mt);
+	xfree(mt, sizeof(multiset_table));
 }
 
 static unsigned int cms_hash(const char * s)
