@@ -4,13 +4,15 @@
 /* All rights reserved                                                   */
 /*                                                                       */
 /* Use of the link grammar parsing system is subject to the terms of the */
-/* license set forth in the LICENSE file included with this software,    */ 
-/* and also available at http://www.link.cs.cmu.edu/link/license.html    */
+/* license set forth in the LICENSE file included with this software.    */ 
 /* This license allows free redistribution and use in source and binary  */
 /* forms, with or without modification, subject to certain conditions.   */
 /*                                                                       */
 /*************************************************************************/
+
+#include "api-types.h"
+
 String_set * string_set_create(void);
-char *       string_set_add(const char * source_string, String_set * ss);
-char *       string_set_lookup(const char * source_string, String_set * ss);
+const char * string_set_add(const char * source_string, String_set * ss);
+const char * string_set_lookup(const char * source_string, String_set * ss);
 void         string_set_delete(String_set *ss);
